==> haskell-criterion-measurement-0.2.1.0-54-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 criterion-measurement
version:              0.2.1.0
visibility:           public
id:                   criterion-measurement-0.2.1.0-FALFlPzP3awFEszRNLF8Qy
key:                  criterion-measurement-0.2.1.0-FALFlPzP3awFEszRNLF8Qy
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  8af03418f6d7ad3b84cbbd9a0aa05ea3
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/criterion-measurement-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/criterion-measurement-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion-measurement
hs-libraries:         HScriterion-measurement-0.2.1.0-FALFlPzP3awFEszRNLF8Qy
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8 base-4.16.4.0
    base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd binary-0.8.9.0
    containers-0.6.5.1 deepseq-1.4.6.1 ghc-prim-0.8.0
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-measurement-0.2.1.0-63-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 criterion-measurement
version:              0.2.1.0
visibility:           public
id:                   criterion-measurement-0.2.1.0-4yiRO8RKFov2kzFpEpowYo
key:                  criterion-measurement-0.2.1.0-4yiRO8RKFov2kzFpEpowYo
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  1d7491a286f0432111486fb6432933a2
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/criterion-measurement-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/criterion-measurement-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion-measurement
hs-libraries:         HScriterion-measurement-0.2.1.0-4yiRO8RKFov2kzFpEpowYo
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd binary-0.8.9.0
    containers-0.6.5.1 deepseq-1.4.6.1 ghc-prim-0.8.0
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
